==> create-dragons-plus-1.2.1-sources.jar: plus/dragons/createdragonsplus/data/recipe/integration/IntegrationResult.java <==
/*
 * Copyright (C) 2025  DragonsPlus
 * SPDX-License-Identifier: LGPL-3.0-or-later
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package plus.dragons.createdragonsplus.data.recipe.integration;

import com.mojang.serialization.Codec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.minecraft.core.component.DataComponentPatch;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.util.ExtraCodecs;
import net.minecraft.world.item.ItemStack;

public record IntegrationResult(ItemStack delegate, ResourceLocation id) {
    public static Codec<IntegrationResult> CODEC = RecordCodecBuilder.create(instance -> instance.group(
            ResourceLocation.CODEC.fieldOf("id")
                    .forGetter(IntegrationResult::id),
            ExtraCodecs.intRange(1, 99).fieldOf("count").orElse(1)
                    .forGetter(result -> Math.max(result.delegate.getCount(), 1)),
            DataComponentPatch.CODEC
                    .optionalFieldOf("components", DataComponentPatch.EMPTY)
                    .forGetter(result -> result.delegate.getComponentsPatch())
    ).apply(instance, (id, count, components) -> {
        throw new UnsupportedOperationException("Can not decode with encode-only codec");
    }));
}

==> create-dragons-plus-1.8.4-sources.jar: plus/dragons/createdragonsplus/data/recipe/integration/IntegrationResult.java <==
/*
 * Copyright (C) 2025  DragonsPlus
 * SPDX-License-Identifier: LGPL-3.0-or-later
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package plus.dragons.createdragonsplus.data.recipe.integration;

import com.mojang.serialization.Codec;
import com.mojang.serialization.codecs.RecordCodecBuilder;
import net.minecraft.core.component.DataComponentPatch;
import net.minecraft.resources.ResourceLocation;
import net.minecraft.util.ExtraCodecs;
import net.minecraft.world.item.ItemStack;

public record IntegrationResult(ItemStack delegate, ResourceLocation id) {
    public static Codec<IntegrationResult> CODEC = RecordCodecBuilder.create(instance -> instance.group(
            ResourceLocation.CODEC.fieldOf("id")
                    .forGetter(IntegrationResult::id),
            ExtraCodecs.intRange(1, 99).fieldOf("count").orElse(1)
                    .forGetter(result -> Math.max(result.delegate.getCount(), 1)),
            DataComponentPatch.CODEC
                    .optionalFieldOf("components", DataComponentPatch.EMPTY)
                    .forGetter(result -> result.delegate.getComponentsPatch()))
            .apply(instance, (id, count, components) -> {
                throw new UnsupportedOperationException("Can not decode with encode-only codec");
            }));
}
